@@ -1,16 +1,12 @@
-
-Isoqqstat <- function (x, y, fudge, niter) 
+ Isoqqstat <- function (x, y, fudge, niter) 
 {
     xiter.index <- t(sapply(1:niter, function(i) sample(x)))
     to1 <- to2 <- to3 <- to4 <- to5 <- matrix(0, nrow(y), niter)
     fudge.factor <- switch(fudge, pooled = Isofudge(x, y), none = c(rep(0, 
         5)))
-  
-    total <-niter
-    # create progress bar
-    pb <- winProgressBar(title = "progress bar", min = 0,
-                     max = total, width = 300)
-
+    total <- niter
+    pb <- tkProgressBar(title = "progress bar", min = 0, max = total, 
+        width = 300)
     for (i in 1:niter) {
         yyy0 <- IsoGenemSAM(xiter.index[i, ], as.matrix(y), fudge.factor)
         to1[, i] <- sort(yyy0[[1]])
@@ -18,8 +14,8 @@ Isoqqstat <- function (x, y, fudge, niter)
         to3[, i] <- sort(yyy0[[3]])
         to4[, i] <- sort(yyy0[[4]])
         to5[, i] <- sort(yyy0[[5]])
-     setWinProgressBar(pb, i , title=paste( round(i /total*100, 0),
-                                         "% done"))
+        setTkProgressBar(pb, i, title = paste(round(i/total * 
+            100, 0), "% done"))
     }
     close(pb)
     L <- IsoGenemSAM(x, as.matrix(y), fudge.factor)
@@ -56,5 +52,4 @@ Isoqqstat <- function (x, y, fudge, niter)
     res <- list(aa1 = aa1, to1 = to1, aa2 = aa2, to2 = to2, aa3 = aa3, 
         to3 = to3, aa4 = aa4, to4 = to4, aa5 = aa5, to5 = to5)
     return(res)
-
 }
